@@ -3,19 +3,19 @@ package Config::Tiny;
 # If you thought Config::Simple was small...
 
 use strict;
+use 5.008001; # For the utf8 stuff.
 
 # Warning: There is another version line, in t/02.main.t.
 
-our $VERSION = '2.24';
+our $VERSION = '2.28';
 
 BEGIN {
-	require 5.008001; # For the utf8 stuff.
 	$Config::Tiny::errstr  = '';
 }
 
-# Create an empty object.
+# Create an object.
 
-sub new { return bless {}, shift }
+sub new { return bless defined $_[1] ? $_[1] : {}, $_[0] }
 
 # Create an object from a file.
 
@@ -31,9 +31,9 @@ sub read
 	$encoding = $encoding ? "<:$encoding" : '<';
 	local $/  = undef;
 
-	open( CFG, $encoding, $file ) or return $class -> _error( "Failed to open file '$file' for reading: $!" );
-	my $contents = <CFG>;
-	close( CFG );
+	open(my $CFG, $encoding, $file) or return $class -> _error( "Failed to open file '$file' for reading: $!" );
+	my $contents = <$CFG>;
+	close($CFG );
 
 	return $class -> _error("Reading from '$file' returned undef") if (! defined $contents);
 
@@ -112,9 +112,9 @@ sub write
 
 	return undef unless defined $string;
 
-	open( CFG, $encoding, $file ) or return $self->_error("Failed to open file '$file' for writing: $!");
-	print CFG $string;
-	close CFG;
+	open(my $CFG, $encoding, $file) or return $self->_error("Failed to open file '$file' for writing: $!");
+	print $CFG $string;
+	close($CFG);
 
 	return 1;
 
@@ -181,9 +181,14 @@ Config::Tiny - Read/Write .ini style files with as little code as possible
 	# In your program
 	use Config::Tiny;
 
-	# Create a config
+	# Create an empty config
 	my $Config = Config::Tiny->new;
 
+	# Create a config with data
+	my $config = Config::Tiny->new({
+		_ => { rootproperty => "Bar" },
+		section => { one => "value", Foo => 42 } });
+
 	# Open the config
 	$Config = Config::Tiny->read( 'file.conf' );
 	$Config = Config::Tiny->read( 'file.conf', 'utf8' ); # Neither ':' nor '<:' prefix!
@@ -259,9 +264,16 @@ Returns a string representing the most recent error, or the empty string.
 
 You can also retrieve the error message from the C<$Config::Tiny::errstr> variable.
 
-=head2 new()
+=head2 new([$config])
 
-The constructor C<new> creates and returns an empty C<Config::Tiny> object.
+Here, the [] indicate an optional parameter.
+
+The constructor C<new> creates and returns a C<Config::Tiny> object.
+
+This will normally be a new, empty configuration, but you may also pass a
+hashref here which will be turned into an object of this class. This hashref
+should have a structure suitable for a configuration file, that is, a hash of
+hashes where the key C<_> is treated specially as the root section.
 
 =head2 read($filename, [$encoding])
 
@@ -415,7 +427,7 @@ L<https://github.com/ronsavage/Config-Tiny.git>
 
 Bugs should be reported via the CPAN bug tracker at
 
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Config-Tiny>
+L<https://github.com/ronsavage/Config-Tiny/issues>
 
 For other issues, or commercial enhancement or support, contact the author.
 
